/*
+-----------------------------------------------------------------+
| MODULE NAME:                                                    |
| sgTemplate_LineOverlay                                          |
|                                                                 |
| TYPE:                                                           |
| SAS macro code                                                  |
|                                                                 |
| DESCRIPTION:                                                    |
| Creates a StatGraph Template for overlay Line Charts used in the|
| SWA42.                                                          |
|                                                                 |
| Example:                                                        |
|                                                                 |    
|                                                                 |
| SAS VERSION:                                                    |
| SAS Version that this software unit was developed for: 9.2      |
|                                                                 |
|                                                                 |
| INPUT:                                                          |
|-----------------+-----------------------------------------------|
| Name            | Description                                   |
|-----------------+-----------------------------------------------|
|                                                                 |
| d_userTitle        | graph title                                |     
| d_userSubTitle     | graph subtitle                             |     
| d_userFootnote     | graph footnote                             |
| d_reportVar        | reporting variable                         |
| d_analysisVar      | analysis variable                          |
| d_useByVar         | flag to indicate if by var is to be used   |
| d_byVar            | grouping/by variable                       |
|                                                                 |
| OUTPUT:                                                         |
| This code creates a statgraph template for use analyses which   |
| use line charts with mature/immature (actual/forecast) in their | 
|          output. These analyses include:                        |
|                                                                 |                                                              
| 1. Forecasting                                                  |
| 2. Exposure                                                     |
| 3. Trend by Exposure                                            |
| 4. Trend Chart                                                  |
|                                                                 |
| CALLS:                                                          |
| NONE                                                            |
|                                                                 |
| PRECONDITIONS:                                                  |
| NONE                                                            |
|                                                                 |
| POSTCONDITIONS:                                                 |
| NONE                                                            |
|                                                                 |
| DEVELOPMENT/MAINTENANCE HISTORY:                                |
| DATE     BY      NOTE                                           |
| 08Nov08  sindok  initial code for simple line chart             |
| 02Feb09  wehuan  modified for mature/immature lines chart for 4 |
|                  analyses.                                      |
| 02Mar09  gunedu  Added r15=col15 to rolename option for trendexp|
| 12Mar09  wehuan  Changed a typo for exposure                    |
| 20Mar09  wehuan  Fix defect S0567235                            |
| 25Mar09  wehuan  Fix defect S0570608                            |       
| 26Mar09  sindok  Added option BREAK=TRUE for addressing gaps    |
|                  in lines.                                      |
| 02May09  atbroo  Replacing dynamic var d_displayGrid with mvar  |
|                  g_displayGrid                                  |
| 20May09  atbroo  Streamlined template to allow for multiple     |
|                  markers                                        |
| 20May09  atbroo  Streamlined template to allow for multiple     |
|                  markers                                        |
| 12Jun09  atbroo  adding labels and third plot                   |
| 09Jul09  sinsaa  adding extra roles. Fixed defect S0591907      |
| 10Jul09  sinsaa  Fixed S0593349                                 |
| 26Apr2010 sinkah  Made changes for failure relation requirment  |
| 06Mar2012 sinkah  Made changes for the defect S0839615          | 
+-----------------------------------------------------------------+
+-----------------------------------------------------------------+
| Copyright  2003 by SAS Institute Inc., Cary, NC 27513 USA       |
| ---All Rights Reserved.                                         |
+-----------------------------------------------------------------+
*/

/*
SINDOK: 10th Nov, 2008
1. This code will be executed as a part of install/config process. It will create a statgraph
template which will be stored in an item store. Currently I have designated SASHELP.tmplmst as
the item store. We will have to revisit the location part once we have a decision. parmsl can 
be a possible location.




*/



proc template;
define statgraph swagraphs.lpoverlay/ store=usertl.templat;
dynamic d_userTitle
        d_userSubTitle
        d_userFootnote
        d_xlabel
        d_ylabel

        d_legendTitle
        d_legendType "plot1, plot2, plot3, all, unintialized=no legend, new"

        d_vrefValue
        d_vrefLabel

        d_x1
        d_y1
        d_group1 
        d_index1 "a numeric (>0) column"
        d_display1 "standard (line only), all (line and markers)"
        d_lineAttrs1 "GraphData1, GraphData2, etc. "
        d_markerAttrs1 "GraphData1, GraphData2, etc. "
        d_legendlabel1 "only used for legnedType=all"

        d_x2
        d_y2
        d_group2
        d_index2 "a numeric (>0) column"
        d_display2 "standard (line only), all (line and markers)"
        d_lineAttrs2 "GraphData1, GraphData2, etc. "
        d_markerAttrs2 "GraphData1, GraphData2, etc. "
        d_legendlabel2 "only used for legnedType=all"

        d_x3
        d_y3
        d_group3
        d_index3 "a numeric (>0) column"
        d_display3 "standard (line only), all (line and markers)"
        d_lineAttrs3 "GraphData1, GraphData2, etc. "
        d_markerAttrs3 "GraphData1, GraphData2, etc. "
        d_legendlabel3 "only used for legnedType=all"

		d_xvar1
		d_yvar1
		d_xvar2
		d_yvar2
		d_markerAttrsy1
		d_markerAttrsy2
		d_ylabel2
		d_xlabel2
		d_lineattrsy1
		d_lineattrsy2

        col1
        col2 
        col3
        col4
        col5
        col6
        col7
        col8
        col9
        col10
        col11
        col12
        col13
        col14
        col15
        col16
        col17
        col18
        col19
        col20
        col21
        col22
        col23
        col24
        col25
		col26
        col27
        col28
        col29
        col30
        col31
        col32
        col33
        col34
        col35
		col36
        col37
        col38
        col39
        col40  
;

mvar g_displayGrid;

begingraph;
  entrytitle d_userTitle;
  entrytitle d_userSubTitle;
  entryfootnote halign=left d_userFootnote;
  
 
  layout overlay/     
     yaxisopts=( 
       label=d_ylabel
       griddisplay=g_displayGrid
       display=all 
       )

	  y2axisopts=( 
       label=d_ylabel2
       griddisplay=g_displayGrid
       display=all 
       )

     xaxisopts=( 
       label=d_xlabel
       griddisplay=g_displayGrid
       display=all  
       )

      x2axisopts=( 
       label=d_xlabel2
       griddisplay=g_displayGrid
       display=all  
       )
       ;
 
     seriesplot x=d_x1 y=d_y1 / name="plot1" legendlabel=d_legendLabel1
                                group=d_group1 index=d_index1
                                display=d_display1 lineattrs=d_lineAttrs1
                                markerattrs=d_markerAttrs1
                                connectorder=xaxis break=true
                rolename=(r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7
                          r8=col8 r9=col9 r10=col10 r11=col11 r12=col12 r13=col13
                          r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19
                          r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25
						  r26=col26 r27=col27 r28=col28 r29=col29 r30=col30 r31=col31
						  r32=col32 r33=col33 r34=col34 r35=col35 r36=col36 r37=col37
 						  r38=col38 r39=col39 r40=col40)
                TIP =(X Y group);
    
                                               
     seriesplot x=d_x2 y=d_y2 / name="plot2" legendlabel=d_legendLabel2
                                group=d_group2 index=d_index2
                                display=d_display2 lineattrs=d_lineAttrs2
                                markerattrs=d_markerAttrs2
                                connectorder=xaxis break=true
                rolename=(r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7
                          r8=col8 r9=col9 r10=col10 r11=col11 r12=col12 r13=col13
                          r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19
                          r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25
						  r26=col26 r27=col27 r28=col28 r29=col29 r30=col30 r31=col31
						  r32=col32 r33=col33 r34=col34 r35=col35 r36=col36 r37=col37
 						  r38=col38 r39=col39 r40=col40)
                TIP =(X Y group);
    
     seriesplot x=d_x3 y=d_y3 / name="plot3" legendlabel=d_legendLabel3
                                group=d_group3 index=d_index3
                                display=d_display3 lineattrs=d_lineAttrs3
                                markerattrs=d_markerAttrs3
                                connectorder=xaxis break=true
                rolename=(r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7
                          r8=col8 r9=col9 r10=col10 r11=col11 r12=col12 r13=col13
                          r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19
                          r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25
						  r26=col26 r27=col27 r28=col28 r29=col29 r30=col30 r31=col31
						  r32=col32 r33=col33 r34=col34 r35=col35 r36=col36 r37=col37
 						  r38=col38 r39=col39 r40=col40)
                TIP =(X Y group);
    

    seriesplot x=d_xvar1 y=d_yvar1 / name="Confidence" display=d_display2 lineattrs=d_lineattrsy1
                                  markerattrs=d_markerAttrsy1 connectorder=xaxis break=true 
                   rolename=(r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7
                             r8=col8 r9=col9 r10=col10 r11=col11 r12=col12 r13=col13
                             r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19
                             r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25
                             r26=col26 r27=col27 r28=col28 r29=col29 r30=col30 r31=col31
			     r32=col32 r33=col33 r34=col34 r35=col35 r36=col36 r37=col37
 			     r38=col38 r39=col39 r40=col40)
 			     
                   TIP =(X Y group);


    seriesplot  x=d_xvar2 y=d_yvar2 / yaxis=y2 name="Support" display=d_display2 lineattrs=d_lineattrsy2
                                  markerattrs=d_markerAttrsy2 connectorder=xaxis break=true 
               rolename= (r1=col1 r2=col2 r3=col3 r4=col4 r5=col5 r6=col6 r7=col7
                          r8=col8 r9=col9 r10=col10 r11=col11 r12=col12 r13=col13
                          r14=col14 r15=col15 r16=col16 r17=col17 r18=col18 r19=col19
                          r20=col20 r21=col21 r22=col22 r23=col23 r24=col24 r25=col25
						  r26=col26 r27=col27 r28=col28 r29=col29 r30=col30 r31=col31
						  r32=col32 r33=col33 r34=col34 r35=col35 r36=col36 r37=col37
 						  r38=col38 r39=col39 r40=col40)
                TIP =(X Y group);

     referenceline Y = d_vrefValue / CURVELABEL=d_vrefLabel;

     if (d_legendType =: "all")
        discretelegend "plot1" "plot2" "plot3" /Title=d_legendTitle;
     else if (d_legendType =: "plot1" )
        discretelegend "plot1" /Title=d_legendTitle;
     else if (d_legendType =: "plot2" )
        discretelegend "plot2" /Title=d_legendTitle;
     else if (d_legendType =: "plot3" )
        discretelegend "plot3" /Title=d_legendTitle;
     else if (d_legendType =: "new")
	    discretelegend  "Support" "Confidence" / Title=d_legendTitle; 
     endif;
     endif;
     endif;
     endif;
	 endif;

  endlayout;

endgraph;
end;
run;
